Skip to contents

Extracts the tariff class splits as a numeric vector.

Usage

# S3 method for class 'constructtariffclasses'
as.vector(x, ...)

Arguments

x

An object of class "constructtariffclasses".

...

Further arguments passed to or from other methods (ignored).

Value

A numeric vector with the split points of the tariff classes.