View source: R/model_get_data.R
| construct_model_points | R Documentation |
rating_grid()construct_model_points() is deprecated in favour of rating_grid().
construct_model_points(
x,
group_by = NULL,
exposure = NULL,
exposure_by = NULL,
aggregate_cols = NULL,
drop_na = FALSE,
group_vars = NULL,
agg_cols = NULL
)
x |
A |
group_by |
Optional character vector with the variables that define the
rating-grid points. If |
exposure |
Optional character; name of the exposure column to aggregate. |
exposure_by |
Optional character; name of a column used to split exposure or counts, for example a year variable. |
aggregate_cols |
Optional character vector with additional numeric
columns to aggregate using |
drop_na |
Logical; if |
group_vars, agg_cols |
Deprecated argument names. Use |
See rating_grid().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.