View source: R/gam_construct_tariff_classes.R
| construct_tariff_classes | R Documentation |
derive_tariff_segments()construct_tariff_classes() is deprecated as of version 0.9.0. Use
derive_tariff_segments() instead.
construct_tariff_classes(
object,
complexity = 0,
max_iterations = 10000,
population_size = 200,
seed = 1,
alpha = NULL,
niterations = NULL,
ntrees = NULL
)
object |
A |
complexity |
Deprecated. Use |
max_iterations |
Positive integer. Maximum number of evolutionary search iterations. This is an advanced algorithm-control parameter. |
population_size |
Positive integer. Number of candidate trees maintained during the evolutionary search. This is an advanced algorithm-control parameter. |
seed |
Single finite whole number used to reproduce the evolutionary search. |
alpha |
Deprecated. Use |
niterations |
Deprecated. Use |
ntrees |
Deprecated. Use |
See derive_tariff_segments().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.