Skip to contents

Displays the tariff class splits of an object created by construct_tariff_classes().

Usage

# S3 method for class 'constructtariffclasses'
print(x, ...)

Arguments

x

An object of class "constructtariffclasses".

...

Further arguments passed to or from other methods (ignored).

Value

Invisibly returns x.