View source: R/model_rating_table_deprecated.R
| rating_factors2 | R Documentation |
Legacy interface. Prefer rating_table() for fitted models in the new
workflow, but this function remains available.
rating_factors2(
model,
model_data = NULL,
exposure = TRUE,
exposure_name = NULL,
colname = "estimate",
exponentiate = TRUE,
round_exposure = 0
)
model |
glm object produced by |
model_data |
Optional data.frame used to create glm object. If |
exposure |
Logical or character. If |
exposure_name |
Optional name for the exposure column in the output. |
colname |
name of coefficient column |
exponentiate |
logical indicating whether or not to exponentiate the coefficient estimates. Defaults to TRUE. |
round_exposure |
number of digits for exposure (defaults to 0) |
A data frame with rating factor coefficients for one model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.