summary.refinement_audit: Summarise a refinement audit

View source: R/model_refinement_audit.R

summary.refinement_auditR Documentation

Summarise a refinement audit

Description

Return and print the provenance, ordered refinement steps, total portfolio effect and the largest absolute level changes from audit_refinement().

Usage

## S3 method for class 'refinement_audit'
summary(object, top_n = 10, ...)

Arguments

object

A refinement_audit object.

top_n

Non-negative whole number controlling how many level changes are included in the printed summary.

...

Currently unused.

Value

An object of class summary.refinement_audit containing the audit metadata, formulas, steps, portfolio result and selected level impacts.

See Also

audit_refinement()


insurancerating documentation built on Sept. 1, 2026, 5:08 p.m.