Add expert-based relativities to a refinement workflow
Source:R/model_refinement.R
add_relativities.RdAdds a relativities step to a rating_refinement object.
Usage
add_relativities(
model,
model_variable,
split_variable,
relativities,
exposure,
normalize = TRUE
)Arguments
- model
Object of class
rating_refinement, usually created withprepare_refinement().- model_variable
Character string. Existing variable in the GLM. Levels of this variable can be split into more detailed groups.
- split_variable
Character string. More granular portfolio variable that defines the split groups.
- relativities
Named list of data.frames, usually created with
relativities_list()andsplit_level().- exposure
Character string. Exposure column.
- normalize
Logical.
Details
add_relativities() is only available within the new refinement workflow
and should be used in combination with prepare_refinement() and refit().