Add coefficient restrictions to a refinement workflow
Source:R/model_refinement.R
add_restriction.RdAdds a restriction step to a rating_refinement object.
restrict_coef() is deprecated as of version 0.9.0.
Please use the refinement workflow instead:
prepare_refinement(model) |>
add_restriction(...) |>
refit()Arguments
- model
Object of class
rating_refinement, usually created withprepare_refinement().- restrictions
data.frame with exactly two columns: the original risk factor level and the replacement relativity to use in the refined tariff.
Details
add_restriction() is part of the new refinement workflow and is intended
to be used in combination with prepare_refinement() and refit().
The legacy function restrict_coef() remains the only function that should
be applied directly to a model object.