Skip to contents

Adds a restriction step to a rating_refinement object.

Usage

add_restriction(model, restrictions)

restrict_coef(model, restrictions)

Arguments

model

Object of class rating_refinement.

restrictions

data.frame with two columns containing restricted data.

Value

Object of class rating_refinement.

Details

add_restriction() is part of the new refinement workflow and is intended to be used in combination with prepare_refinement() and refit().

The legacy function restrict_coef() remains the only function that should be applied directly to a model object.