View source: R/model_performance_bootstrap_rmse.R
| autoplot.bootstrap_performance | R Documentation |
autoplot() method for objects created by bootstrap_performance().
Produces a histogram and density plot of the bootstrapped RMSE values,
with the RMSE of the original fitted model shown as a dashed vertical line.
Optionally, 95% quantile bounds are shown as dotted vertical lines.
## S3 method for class 'bootstrap_performance'
autoplot(object, fill = "#E6E6E6", color = NA, ...)
object |
An object of class |
fill |
Fill color of the histogram bars. Default = |
color |
Border color of the histogram bars. Default = |
... |
Additional arguments passed to |
A ggplot2::ggplot object.
Martin Haringa
## Not run:
mod1 <- glm(nclaims ~ age_policyholder, data = MTPL,
offset = log(exposure), family = poisson())
x <- bootstrap_performance(mod1, MTPL, n_resamples = 100,
show_progress = FALSE)
autoplot(x)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.