View source: R/model_performance_residuals.R
| autoplot.check_residuals | R Documentation |
autoplot() method for objects created by check_residuals().
Produces a simulation-based uniform QQ-plot of the residuals, with the
Kolmogorov-Smirnov p-value shown in the subtitle.
Optionally prints a message about whether deviations are detected.
## S3 method for class 'check_residuals'
autoplot(object, show_message = TRUE, max_points = 1000, ...)
object |
An object of class |
show_message |
Logical. If TRUE (default), prints a short message based on the p-value from the KS test. |
max_points |
Maximum number of QQ-plot points to display. If the
residual check contains more points, an evenly spaced subset is shown. Use
|
... |
Additional arguments passed to |
A ggplot2::ggplot object.
Martin Haringa
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.