Automatically create a ggplot for objects obtained from fit_truncated_dist()
Source:R/truncated_distributions.R
autoplot.truncated_dist.RdCreates a plot of the empirical cumulative distribution function (ECDF) of the observed truncated data together with the fitted truncated CDF.
Arguments
- object
An object produced by
fit_truncated_dist().- geom_ecdf
Character string indicating how to display the ECDF. Must be one of
"point"or"step".- xlab
Title of the x axis. Defaults to
"severity".- ylab
Title of the y axis. Defaults to
"cumulative proportion".- ylim
Numeric vector of length 2 specifying y-axis limits.
- xlim
Numeric vector of length 2 specifying x-axis limits.
- print_title
Logical. If
TRUE, print title and subtitle.- print_dig
Integer. Number of digits for parameter estimates in the subtitle.
- print_trunc
Integer. Number of digits used for truncation bounds.
- ...
Currently unused.