Deprecated alias for bootstrap_performance()
Source: R/model_performance_bootstrap_rmse.R
bootstrap_rmse.Rdbootstrap_rmse() is deprecated in favour of bootstrap_performance().
Objects returned by bootstrap_rmse() keep class "bootstrap_rmse" for
backward compatibility and also inherit from "bootstrap_performance".
Usage
bootstrap_rmse(
model,
data,
n = 50,
frac = 1,
metric = "rmse",
sampling = c("bootstrap", "split"),
show_progress = TRUE,
rmse_model = NULL
)Arguments
- model
A fitted model object that can be updated on resampled data.
- data
Data frame containing the model response and predictors.
- n
Deprecated. Use
n_resamplesinbootstrap_performance()instead.- frac
Deprecated. Use
sample_fractioninbootstrap_performance()instead.- metric
Character string. Performance metric to compute. Currently only
"rmse"is supported.- sampling
Character string. Sampling scheme.
"bootstrap"samples training rows with replacement and evaluates on out-of-bag rows whensample_fraction < 1."split"samples training rows without replacement and evaluates on the remaining rows whensample_fraction < 1.- show_progress
Logical. Show a progress bar during resampling. Default is
TRUE.- rmse_model
Optional finite numeric RMSE for the original fitted model. If
NULL, it is calculated frommodelanddata.