| $.rating_table | R Documentation |
A rating_table is a data frame. This method keeps the historical x$df
accessor available while allowing ordinary $ access to table columns.
Package metadata is returned only when the requested name is not a column.
## S3 method for class 'rating_table'
x$name
x |
A |
name |
Column or legacy component name. |
A table column, the underlying data frame for name = "df", or a
stored metadata component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.