Deprecated alias for derive_tariff_segments()
Source: R/gam_construct_tariff_classes.R
construct_tariff_classes.Rdconstruct_tariff_classes() is deprecated as of version 0.9.0. Use
derive_tariff_segments() instead.
Usage
construct_tariff_classes(
object,
complexity = 0,
max_iterations = 10000,
population_size = 200,
seed = 1,
alpha = NULL,
niterations = NULL,
ntrees = NULL
)Arguments
- object
A
"risk_factor_gam"object returned byrisk_factor_gam(). Legacy"riskfactor_gam"and"fitgam"classes are accepted for compatibility.- complexity
Deprecated. Use
segmentation_penaltyinstead.- max_iterations
Positive integer. Maximum number of evolutionary search iterations. This is an advanced algorithm-control parameter.
- population_size
Positive integer. Number of candidate trees maintained during the evolutionary search. This is an advanced algorithm-control parameter.
- seed
Single finite whole number used to reproduce the evolutionary search.
- alpha
Deprecated. Use
segmentation_penaltyinstead.- niterations
Deprecated. Use
max_iterationsinstead.- ntrees
Deprecated. Use
population_sizeinstead.