View source: R/gam_construct_tariff_classes.R
| construct_tariff_classes | R Documentation |
derive_tariff_segments()construct_tariff_classes() is deprecated as of version 0.9.0. Use
derive_tariff_segments() instead.
construct_tariff_classes(
object,
complexity = 0,
max_iterations = 10000,
population_size = 200,
seed = 1,
alpha = NULL,
niterations = NULL,
ntrees = NULL
)
object |
An object of class |
complexity |
Numeric. Controls the complexity penalty used when deriving segments. Higher values generally yield fewer tariff segments. Default = 0. |
max_iterations |
Integer. Maximum number of search iterations used by the underlying grouping algorithm. Default = 10000. |
population_size |
Integer. Number of candidate trees used by the underlying grouping algorithm. Default = 200. |
seed |
Integer, seed for the random number generator (for reproducibility). |
alpha |
Deprecated. Use |
niterations |
Deprecated. Use |
ntrees |
Deprecated. Use |
See derive_tariff_segments().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.