derive_tariff_segments()construct_tariff_classes() is deprecated as of version 0.9.0. Use
derive_tariff_segments() instead.
construct_tariff_classes(
object,
complexity = 0,
max_iterations = 10000,
population_size = 200,
seed = 1,
alpha = NULL,
niterations = NULL,
ntrees = NULL
)See derive_tariff_segments().
A "risk_factor_gam" object returned by
risk_factor_gam(). Legacy "riskfactor_gam" and "fitgam" classes are
accepted for compatibility.
Deprecated. Use segmentation_penalty instead.
Positive integer. Maximum number of evolutionary search iterations. This is an advanced algorithm-control parameter.
Positive integer. Number of candidate trees maintained during the evolutionary search. This is an advanced algorithm-control parameter.
Single finite whole number used to reproduce the evolutionary search.
Deprecated. Use segmentation_penalty instead.
Deprecated. Use max_iterations instead.
Deprecated. Use population_size instead.