Skip to contents

Start a refinement workflow for a fitted GLM. Refinement steps such as smoothing, restrictions and expert-based relativities can be added sequentially and are only applied once refit() is called.

Usage

prepare_refinement(model, data = NULL)

Arguments

model

Object of class glm.

data

Optional data.frame with the same rows and model variables as the fitted GLM. If NULL, the data are retrieved from the model object.

Value

Object of class rating_refinement.