rating_factors() is deprecated as of version 0.8.0. Use
rating_table() instead.
Usage
rating_factors(
...,
model_data = NULL,
exposure = TRUE,
exposure_name = NULL,
signif_stars = FALSE,
exponentiate = TRUE,
round_exposure = 0
)Arguments
- ...
glm object(s) produced by
glm(),refit()orrefit_glm()- model_data
Optional data.frame used to create the model(s). If
NULL, the function tries to usemodel$datafor each supplied model.- exposure
Logical or character. If
TRUE(default), exposure is added if it can be inferred from the model. IfFALSE, no exposure is added. If a character string is supplied, it is interpreted as the exposure column name.- exposure_name
Deprecated. Use
exposure_outputinrating_table()instead.- signif_stars
Deprecated. Use
significanceinrating_table()instead.- exponentiate
Logical. If
TRUE(default), coefficients are exponentiated and shown as relativities. IfFALSE, coefficients are shown on the model scale.- round_exposure
number of digits for exposure (defaults to 0)
Value
See rating_table().