Legacy interface. Prefer rating_table() for fitted models in the new
workflow, but this function remains available.
rating_factors2(
model,
model_data = NULL,
exposure = TRUE,
exposure_name = NULL,
colname = "estimate",
exponentiate = TRUE,
round_exposure = 0
)A data frame with rating factor coefficients for one model.
glm object produced by glm()
Optional data.frame used to create glm object. If NULL,
the function tries to use model$data.
Logical or character. If TRUE (default), exposure is added
if it can be inferred from the model. If FALSE, no exposure is added.
If a character string is supplied, it is interpreted as the exposure column
name.
Optional name for the exposure column in the output.
name of coefficient column
logical indicating whether or not to exponentiate the coefficient estimates. Defaults to TRUE.
number of digits for exposure (defaults to 0)