rows_per_date() is deprecated as of version 0.9.0. Use
active_rows_by_date() instead.
Arguments
- df
Deprecated. Use
portfolioinstead.- dates
A
data.frameordata.tablewith event or snapshot dates.- df_begin
Deprecated NSE argument. Use
period_startinstead.- df_end
Deprecated NSE argument. Use
period_endinstead.- dates_date
Deprecated NSE argument. Use
dateinstead.- ...
Deprecated NSE join columns. Use
byinstead.- nomatch
When a row (with interval say,
[a,b]) in x has no match in y, nomatch=NA means NA is returned for y's non-by.y columns for that row of x. nomatch=NULL (default) means no rows will be returned for that row of x.- mult
When multiple rows in y match to the row in x,
multcontrols which values are returned - "all" (default), "first" or "last".