Return and print the provenance, ordered refinement steps, total portfolio
effect and the largest absolute level changes from audit_refinement().
Usage
# S3 method for class 'refinement_audit'
summary(object, top_n = 10, ...)Value
An object of class summary.refinement_audit containing the audit
metadata, formulas, steps, portfolio result and selected level impacts.