View source: R/model_refinement_audit.R
| summary.refinement_audit | R Documentation |
Return and print the provenance, ordered refinement steps, total portfolio
effect and the largest absolute level changes from audit_refinement().
## S3 method for class 'refinement_audit'
summary(object, top_n = 10, ...)
object |
A |
top_n |
Non-negative whole number controlling how many level changes are included in the printed summary. |
... |
Currently unused. |
An object of class summary.refinement_audit containing the audit
metadata, formulas, steps, portfolio result and selected level impacts.
audit_refinement()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.