Return and print the provenance, ordered refinement steps, total portfolio
effect and the largest absolute level changes from audit_refinement().
# S3 method for refinement_audit
summary(object, top_n = 10, ...)An object of class summary.refinement_audit containing the audit
metadata, formulas, steps, portfolio result and selected level impacts.
A refinement_audit object.
Non-negative whole number controlling how many level changes are included in the printed summary.
Currently unused.
audit_refinement()